aboutsummaryrefslogtreecommitdiff
path: root/src/include/lexer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/lexer.h')
-rw-r--r--src/include/lexer.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/include/lexer.h b/src/include/lexer.h
index 173c57d..b2bf9eb 100644
--- a/src/include/lexer.h
+++ b/src/include/lexer.h
@@ -28,6 +28,9 @@ typedef struct LEXER_STRUC {
/* the linked list of tokens generated */
token_t* tokenl;
+ /* pointer to the last token in tokenl */
+ token_t* tokenl_last;
+ /* number of tokens in tokenl */
int tokenc;
} lexer_t;
@@ -37,7 +40,7 @@ lexer_t* lexer_init (char* src);
/* destroy lexer **but not src or tokenl** */
void lexer_destroy (lexer_t* lexer);
/* add token to tokenv */
void lexer_add_token(lexer_t* lexer, token_t* token);
/* add the current character as a token to tokenl -- utility function for
lexer_do_reg() */
@@ -37,7 +40,7 @@ lexer_t* lexer_init (char* src);
/* destroy lexer **but not src or tokenl** */
void lexer_destroy (lexer_t* lexer);
-/* add token to tokenv */
+/* add token to tokenl */
void lexer_add_token(lexer_t* lexer, token_t* token);
/* add the current character as a token to tokenl -- utility function for